@@ -2,9 +2,11 @@
 braindump - record what's on your mind
 
 Usage:
-    braindump [options] [TOPIC]
+    braindump ls
+    braindump [options] [--] [TOPIC]
 
 Arguments:
+    ls                              Output a list of topic files
     TOPIC                           Subject to braindump on, determines filename [default: braindump]
 
 Options:
@@ -20,7 +22,8 @@ import sys
 
 from docopt import docopt
 
-from braindump import __version__, core
+from braindump import __version__
+from braindump.core import FSDumper, BraindumpException
 
 
 def load_settings(settings_file=None):
@@ -49,15 +52,20 @@ def main():
     arguments = docopt(__doc__, version=__version__)
     settings = load_settings(arguments['--settings'])
 
-    if not os.access(settings['braindump_dir'], os.W_OK | os.X_OK):
-        sys.exit('braindump: couldn\'t access braindump dir \'{0}\'. Does it exist/is it writable?'.format(settings['braindump_dir']))
-
+    try:
+        dumper = FSDumper(settings)
+    except BraindumpException as ex:
+        sys.exit(ex.message)
     topic = arguments['TOPIC'] if arguments['TOPIC'] is not None else settings['default_topic']
-    topic.replace(' ', '\ ')
-    dumpfile = topic + settings['file_ext']
-    dumpfile = os.path.join(settings['braindump_dir'], dumpfile)
 
-    if arguments['-m'] is not None:
-        core.quick_add_message(dumpfile, arguments['-m'])
+    if arguments['ls'] is True:
+        topics = dumper.list_topics()
+        output = '{0} braindump topics:'.format(len(topics))
+        for topic in topics:
+            output += '\n- {0}'.format(topic)
+        print output
+    elif arguments['-m'] is not None:
+        if not dumper.quick_add(topic, arguments['-m']):
+            sys.exit('Unable to append message to dumpfile \'{0}\''.format(topic))
     else:
-        core.launch_editor(settings['editor'], dumpfile)
+        dumper.edit_topic(topic)
